# UsageMeasurement

A measurement pertaining to a given usage metric

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**peak** | **int** | The peak value. This is typically the peak over a specified time interval where the interval would be specified in the query string. | [optional] 
**current** | **int** | The current value for the measurement | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


